﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.IO.Ports;
using System.Windows.Threading;
using System.IO;

namespace SorterController
{
    public partial class MainWindow : Window
    {
        private delegate void UpdateUiTextDelegate(string text);
        SerialPort sp = new SerialPort();
        string boxPicked;
        public MainWindow()
        {
            InitializeComponent();
            sp.DataReceived += new SerialDataReceivedEventHandler(DataReceivedHandler); 
        }

        public void DataReceivedHandler(object sender, SerialDataReceivedEventArgs e)
        {
            if (sp.IsOpen)
            {
                string RxString = sp.ReadLine();
                Dispatcher.Invoke(DispatcherPriority.Send, new UpdateUiTextDelegate(ProcessData), RxString);
            }
        }
         
        private void connect_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                string portName = COM.SelectedItem as string;
                sp.PortName = portName;
                sp.BaudRate = 9600;
                sp.Open();
                status.Text = "Připojeno";
            }
            catch (Exception)
            {
                MessageBox.Show("Zvolte platný COM port!");
            }
        }

        private void disconnect_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                sp.Write("0");
                sp.Close();
                status.Text = "Odpojeno";
                manual.Content = "Manual mode";
                send.IsEnabled = bool.Parse("False");
                boxPick.IsEnabled = bool.Parse("False");
                fromF.Text = "-";
            }
            catch (Exception)
            {
                MessageBox.Show("Nejprve se připojte!");
            }
        }


        private void ProcessData(string RxString)
        {
            DateTime timeStamp = DateTime.Now;
            string timeStr = timeStamp.ToString("HH:mm:ss.fff");
            string output = timeStr + " " + RxString;
            fromF.Text = output;
            File.AppendAllText("log.txt", output);

            string stringToCheck = RxString;
            if (stringToCheck.Contains("modra"))
            {
                color.Fill = Brushes.Blue;
            }
            if (stringToCheck.Contains("cervena"))
            {
                color.Fill = Brushes.Red;
            }
            if (stringToCheck.Contains("bila"))
            {
                color.Fill = Brushes.White;
            }
            if (stringToCheck.Contains("prazdna"))
            {
                MessageBox.Show("Vstupní pozice je prázdná!");
            }
        }

        private void manual_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if ((manual.Content as string) == "Manual mode")
                {
                    sp.Write("1");
                    manual.Content = "Auto mode";
                    boxPick.IsEnabled = bool.Parse("True");
                    send.IsEnabled = bool.Parse("True");
                }
                else
                {
                    sp.Write("0");
                    manual.Content = "Manual mode";
                    send.IsEnabled = bool.Parse("False");
                    boxPick.IsEnabled = bool.Parse("False");
                }
            }
            catch
            {
                MessageBox.Show("Nejprve se připojte!");
            }
        }

        private void send_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                sp.Write(boxPicked);
            }
            catch
            {
                MessageBox.Show("Není vybrán box!");
            }
        }

        private void boxPick_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            boxPicked = ((ComboBoxItem)boxPick.SelectedItem).Content.ToString();
        }
    }
}
